<div>
    <div class="hbltpl" data-name="perm_del_tpl">
        <li data-id="{{id}}" class="list-group-item"> {{name}}
            <span class="pull-right label label-danger command deleteperm">x</span>
        </li>
    </div>
    <div class="hbltpl" data-name="perm_add_tpl">
        <li data-id="{{id}}" class="list-group-item"> {{name}}
            <span class=" pull-right label label-success command addperm">+</span>
        </li>
    </div>
    <div class="hbltpl" data-name="user_del_tpl">
        <li data-userid="{{id}}" data-search-item class="list-group-item"> {{username}}
            <span class="pull-right label label-danger command deleteuser">x</span>
        </li>
    </div>
    <div class="hbltpl" data-name="user_add_tpl">
        <li data-userid="{{id}}" class="list-group-item"> {{username}}
            <span class="pull-right label label-success command adduser">+</span>
        </li>
    </div>
</div>