<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<title>Login</title>
	{%- block bootstrapcss %}
		{% include "../shared/bootstrapcss.html" %}
	{%- endblock %}
</head>
<body>
	{% block body %}{% endblock %}
</body>
</html>

