.usermenu {
  margin-bottom: 15px; }

.usermenu ul li.active {
  background-color: grey; }

.usermenu ul {
  list-style-type: none;
  margin: 0;
  padding: 0;
  overflow: hidden;
  background-color: #333333; }

.usermenu ul li {
  float: left; }

.usermenu ul li.active a {
  background-color: #111111; }

.usermenu ul li a {
  display: block;
  color: white;
  text-align: center;
  padding: 16px;
  text-decoration: none; }

.usermenu ul li a:hover {
  background-color: #111111; }

.command {
  cursor: pointer; }

li.list-group-item:nth-child(odd) {
  background: #f9f9f9; }

a.btn {
  color: #fff; }

.ui-state-active,
.ui-widget-content .ui-state-active {
  border: none;
  background: #5cb85c; }

.loginform .form-control {
  width: 100%; }
